import * as THREEJS from "three";
import { DrawCore, Tag } from "@bitbybit-dev/core";
import * as Inputs from "../inputs";
import { Context } from "../context";
import { DrawHelper } from "../draw-helper";
export declare class Draw extends DrawCore {
    readonly drawHelper: DrawHelper;
    readonly context: Context;
    readonly tag: Tag;
    private defaultBasicOptions;
    private defaultPolylineOptions;
    constructor(drawHelper: DrawHelper, context: Context, tag: Tag);
    drawAnyAsync(inputs: Inputs.Draw.DrawAny<THREEJS.Group>): Promise<THREEJS.Group>;
    /**
     * Draws any kind of geometry that does not need asynchronous computing, thus it cant be used with shapes coming from occt or jscad
     * @param inputs Contains options and entities to be drawn
     * @returns ThreeJS Group
     * @group draw sync
     * @shortname draw sync
     */
    drawAny(inputs: Inputs.Draw.DrawAny<THREEJS.Group>): THREEJS.Group;
    /**
     * Creates draw options for basic geometry types like points, lines, polylines, surfaces and jscad meshes
     * @param inputs option definition
     * @returns options
     * @group options
     * @shortname simple
     */
    optionsSimple(inputs: Inputs.Draw.DrawBasicGeometryOptions): Inputs.Draw.DrawBasicGeometryOptions;
    /**
     * Creates draw options for occt shape geometry like edges, wires, faces, shells, solids and compounds
     * @param inputs option definition
     * @returns options
     * @group options
     * @shortname occt shape
     */
    optionsOcctShape(inputs: Inputs.Draw.DrawOcctShapeOptions): Inputs.Draw.DrawOcctShapeOptions;
    private handleJscadMesh;
    private handleJscadMeshes;
    private handleManifoldShape;
    private handleManifoldShapes;
    private handleOcctShape;
    private handleOcctShapes;
    private handleLine;
    private handlePoint;
    private handlePolyline;
    private handleVerbCurve;
    private handleVerbSurface;
    private handlePolylines;
    private handleLines;
    private handlePoints;
    private handleVerbCurves;
    private handleVerbSurfaces;
    private handleTag;
    private handleTags;
    private updateAny;
    private handle;
    private handleAsync;
    private applyGlobalSettingsAndMetadataAndShadowCasting;
}
